using BinaryProvider # requires BinaryProvider 0.3.0 or later

# Parse some basic command-line arguments
const verbose = "--verbose" in ARGS
const prefix = Prefix(get([a for a in ARGS if a != "--verbose"], 1, joinpath(@__DIR__, "usr")))
products = [
    LibraryProduct(prefix, ["libsymspg"], :libsymspg),
]

# Download binaries from hosted location
bin_prefix = "https://github.com/unkcpz/SpglibBuilder/releases/download/v0.1.1"

# Listing of files generated by BinaryBuilder:
download_info = Dict(
    Linux(:i686, libc=:glibc) => ("$bin_prefix/SpglibBuilder.v1.12.2.i686-linux-gnu.tar.gz", "6b8e5a6abea185a8c2f6cc334952d3daa6ce104aa74e35a05176a8eaf648ba5f"),
    Windows(:i686) => ("$bin_prefix/SpglibBuilder.v1.12.2.i686-w64-mingw32.tar.gz", "51ce04864f1db9455eb188e2f0fa2b5709f3bc0a901496739314140193c1b87b"),
    MacOS(:x86_64) => ("$bin_prefix/SpglibBuilder.v1.12.2.x86_64-apple-darwin14.tar.gz", "5fd249bedf11cef33fbfc9a00d212079a6054384782f26b9d5152e88e224e2f6"),
    Linux(:x86_64, libc=:glibc) => ("$bin_prefix/SpglibBuilder.v1.12.2.x86_64-linux-gnu.tar.gz", "2bfe653547c3c6cde9e5db0b59f0a5ba77732c5b3c65eb56dd27986d8100aa45"),
    FreeBSD(:x86_64) => ("$bin_prefix/SpglibBuilder.v1.12.2.x86_64-unknown-freebsd11.1.tar.gz", "39907a3e5a5855f1afd7e2ad472b4943cb193f4a9806ee0051378b650c6ca2b3"),
    Windows(:x86_64) => ("$bin_prefix/SpglibBuilder.v1.12.2.x86_64-w64-mingw32.tar.gz", "6eb021bbde1fbb3a01482e0e83c51f339392aec87bd881371f1514fcc7204f04"),
)

# Install unsatisfied or updated dependencies:
unsatisfied = any(!satisfied(p; verbose=verbose) for p in products)
dl_info = choose_download(download_info, platform_key_abi())
if dl_info === nothing && unsatisfied
    # If we don't have a compatible .tar.gz to download, complain.
    # Alternatively, you could attempt to install from a separate provider,
    # build from source or something even more ambitious here.
    error("Your platform (\"$(Sys.MACHINE)\", parsed as \"$(triplet(platform_key_abi()))\") is not supported by this package!")
end

# If we have a download, and we are unsatisfied (or the version we're
# trying to install is not itself installed) then load it up!
if unsatisfied || !isinstalled(dl_info...; prefix=prefix)
    # Download and install binaries
    install(dl_info...; prefix=prefix, force=true, verbose=verbose)
end

# Write out a deps.jl file that will contain mappings for our products
write_deps_file(joinpath(@__DIR__, "deps.jl"), products, verbose=verbose)
